/**
 * Copyright (c) 2008-2011 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://www.sonatype.com/products/nexus/attributions.
 *
 * This program is free software: you can redistribute it and/or modify it only under the terms of the GNU Affero General
 * Public License Version 3 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License Version 3
 * for more details.
 *
 * You should have received a copy of the GNU Affero General Public License Version 3 along with this program.  If not, see
 * http://www.gnu.org/licenses.
 *
 * Sonatype Nexus (TM) Open Source Version is available from Sonatype, Inc. Sonatype and Sonatype Nexus are trademarks of
 * Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation. M2Eclipse is a trademark of the Eclipse Foundation.
 * All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.proxy.item.uid;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.codehaus.plexus.component.annotations.Component;
import org.sonatype.nexus.proxy.item.RepositoryItemUid;

/**
 * The source for attributes implemented in Nexus Core.
 * 
 * @author cstamas
 */
@Component( role = RepositoryItemUidAttributeSource.class, hint = "core" )
public class CoreRepositoryItemUidAttributeSource
    implements RepositoryItemUidAttributeSource
{
    private final Map<Class<?>, Attribute<?>> coreAttributes;

    public CoreRepositoryItemUidAttributeSource()
    {
        Map<Class<?>, Attribute<?>> attrs = new HashMap<Class<?>, Attribute<?>>( 2 );

        attrs.put( IsMetacontentAttribute.class, new IsMetacontentAttribute() );
        attrs.put( IsHiddenAttribute.class, new IsHiddenAttribute() );
        attrs.put( IsMetadataMaintainedAttribute.class, new IsMetadataMaintainedAttribute() );
        attrs.put( IsRemotelyAccessibleAttribute.class, new IsRemotelyAccessibleAttribute() );

        this.coreAttributes = Collections.unmodifiableMap( attrs );
    }

    @Override
    @SuppressWarnings( "unchecked" )
    public <T extends Attribute<?>> T getAttribute( Class<T> attributeKey, RepositoryItemUid subject )
    {
        return (T) coreAttributes.get( attributeKey );
    }
}
